'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactAtomInput = require('@s-ui/react-atom-input');

var _reactAtomInput2 = _interopRequireDefault(_reactAtomInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var BASE_CLASS = 'sui-MoleculeDropdownOption';
var CLASS_CHECKBOX = BASE_CLASS + '-checkbox';
var CLASS_TEXT = BASE_CLASS + '-text';
var CLASS_DISABLED = BASE_CLASS + '--disabled';
var CLASS_HIGHLIGHTED = 'is-highlighted';
var CLASS_HIGHLIGHTED_MARK = BASE_CLASS + '-mark';

var MoleculeDropdownOption = function MoleculeDropdownOption(_ref) {
  var _cx;

  var children = _ref.children,
      selected = _ref.selected,
      checkbox = _ref.checkbox,
      disabled = _ref.disabled,
      highlightQuery = _ref.highlightQuery,
      onSelectKey = _ref.onSelectKey,
      onSelect = _ref.onSelect,
      innerRef = _ref.innerRef,
      value = _ref.value;

  var className = (0, _classnames2.default)(BASE_CLASS, (_cx = {}, (0, _defineProperty3.default)(_cx, CLASS_CHECKBOX, checkbox), (0, _defineProperty3.default)(_cx, CLASS_DISABLED, disabled), (0, _defineProperty3.default)(_cx, 'is-selected', selected), _cx));

  var handleClick = function handleClick(ev) {
    if (!disabled) onSelect(ev, { value: value });
  };

  var highlightOption = function highlightOption(option) {
    if (typeof option !== 'string') return option;
    var regExpHighlight = new RegExp(highlightQuery, 'gi');
    return option.replace(regExpHighlight, '<mark class="' + (0, _classnames2.default)(CLASS_HIGHLIGHTED_MARK, CLASS_HIGHLIGHTED) + '">$&</mark>');
  };

  var handleKeyDown = function handleKeyDown(ev) {
    var key = ev.key;

    var isStringOnSelectKey = typeof onSelectKey === 'string';
    var isPressedOnSelectKey = isStringOnSelectKey ? key === onSelectKey : onSelectKey.includes(key);

    if (isPressedOnSelectKey && !disabled) {
      ev.preventDefault();
      onSelect(ev, { value: value });
    }
  };

  var handleFocus = function handleFocus(ev) {
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleInnerCheckboxFocus = function handleInnerCheckboxFocus(ev) {
    ev.preventDefault();
    innerRef.current.focus();
  };

  return _react2.default.createElement(
    'div',
    {
      ref: innerRef,
      tabIndex: '0',
      className: className,
      onClick: handleClick,
      onKeyDown: handleKeyDown,
      onFocus: handleFocus
    },
    checkbox && _react2.default.createElement(_reactAtomInput2.default, {
      type: 'checkbox',
      checked: selected,
      disabled: disabled,
      onFocus: handleInnerCheckboxFocus
    }),
    highlightQuery ? _react2.default.createElement('span', {
      dangerouslySetInnerHTML: { __html: highlightOption(children) },
      className: CLASS_TEXT
    }) : _react2.default.createElement(
      'span',
      { className: CLASS_TEXT },
      children
    )
  );
};

MoleculeDropdownOption.displayName = 'MoleculeDropdownOption';

MoleculeDropdownOption.propTypes = process.env.NODE_ENV !== "production" ? process.env.NODE_ENV !== "production" ? {
  /** option value */
  value: _propTypes2.default.string.isRequired,

  /** Content to be included in the option */
  children: _propTypes2.default.node,

  /** Contains checkbox */
  checkbox: _propTypes2.default.bool,

  /** Is disabled */
  disabled: _propTypes2.default.bool,

  /** onSelect callback (ev, {value}) */
  onSelect: _propTypes2.default.func,

  /** Is initial selected */
  selected: _propTypes2.default.bool,

  /** Text to be highlighted in the option text if found */
  highlightQuery: _propTypes2.default.string,

  /* key to provoke the onClick callback. Valid any value defined here → https://www.w3.org/TR/uievents-key/#named-key-attribute-values */
  onSelectKey: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.array]),

  /** Custom ref handler that will be assigned to the "target" element */
  innerRef: _propTypes2.default.object
} : {} : {};

MoleculeDropdownOption.defaultProps = {
  checkbox: false,
  disabled: false,
  onSelect: function onSelect() {},
  selected: false,
  onSelectKey: 'Enter',
  innerRef: _react2.default.createRef()
};

exports.default = MoleculeDropdownOption;